velodyne-view(1)

velodyne-view1

Demo for grabbing and visualizing data from a velodyne sensor

Usage

velodyne-view [-v] [-n] [-m <`VLP16`,`HDL32`,`HDL64`,>] [-c
<calib.xml>] [--ip-filter <192.168.1.201>] [--out-pcap
<out>] [-i <in_dataset.pcap>] [-o <out.rawlog>] [--]
[--version] [-h]

Usage examples

Run with all default parameters and show live VLP16 LIDAR scans

velodyne-view

Parses a PCAP file with a LIDAR dump (default params)

velodyne-view --in-pcap DATASET.pcap

Parses a PCAP file with a LIDAR dump (custom calibration file)

velodyne-view --in-pcap DATASET.pcap --calib CALIB.xml

Grab RawLog and PCAP log files from a live VLP16 LIDAR

velodyne-view --out-pcap out --out-rawlog out.rawlog

Grab RawLog and PCAP log files from a live LIDAR with calibration file

velodyne-view --out-pcap out --out-rawlog out.rawlog --calib CALIB.xml

Overview

velodyne-view is a simple application that continuously grabs scans from a Velodyne sensor and displays the 3D point cloud live.

Arguments:

   -v,  --verbose
     Verbose debug output
   -n,  --nologo
     Skip the logo at startup
   -m <`VLP16`,`HDL32`,`HDL64`,>,  --model <`VLP16`,`HDL32`,`HDL64`,>
     If no calibration file is specified, set the model to load default
     values
   -c <calib.xml>,  --calib <calib.xml>
     Optionally, select the calibration XML file for the LIDAR
   --ip-filter <192.168.1.201>
     Only listen to a LIDAR emitting commands from a given IP
   --out-pcap <out>
     If set, grab all packets to a PCAP log file. Set name prefix only.
   -i <in_dataset.pcap>,  --in-pcap <in_dataset.pcap>
     Instead of listening to a live sensor, read data from a PCAP file
   -o <out.rawlog>,  --out-rawlog <out.rawlog>
     If set, grab dataset in rawlog format
   --,  --ignore_rest
     Ignores the rest of the labeled arguments following this flag.
   --version
     Displays version information and exits.
   -h,  --help
     Displays usage information and exits.

Releases

5 releases since Debian 9 (Stretch); the text changed 4 times.

  1. 9
  2. 10
  3. 11
  4. 12
  5. 13

Bugs

Please report bugs at https://github.com/MRPT/mrpt/issues

Authors

velodyne-view is part of the Mobile Robot Programming Toolkit (MRPT), and was originally written by Jose Luis Blanco (University of Almeria).

This manual page was written by Jose Luis Blanco <[email protected]>.

From mrpt-apps 1:2.14.7+ds-1+b3 in Debian 13 (Trixie). Parsed by carta from the page's man source.